@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002,2004 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002,2004 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -27,6 +27,7 @@
 #include <gsf/gsf-input-stdio.h>
 #include <stdio.h>
 #include "libwpd.h"
+#include "GSFStream.h"
 #include "RawListener.h"
 
 int main(int argc, char *argv[])
@@ -65,7 +66,7 @@ int main(int argc, char *argv[])
 		file = argv[1];
 		
 	
-	GError   *err;
+	GError   *err = NULL;
 	GsfInput * input = GSF_INPUT(gsf_input_stdio_new (file, &err));
 	if (input == NULL) 
 	{
@@ -76,7 +77,9 @@ int main(int argc, char *argv[])
 		return 1;
 	}
 
-	WPDConfidence confidence = WPDocument::isFileFormatSupported(input, false);
+	GSFInputStream *gsfInput = new GSFInputStream(input);
+
+	WPDConfidence confidence = WPDocument::isFileFormatSupported(gsfInput, false);
 	if (confidence == WPD_CONFIDENCE_NONE || confidence == WPD_CONFIDENCE_POOR)
 	{
 		printf("ERROR: Unsupported file format!\n");
@@ -84,33 +87,25 @@ int main(int argc, char *argv[])
 	}
 	
 	RawListenerImpl listenerImpl(printIndentLevel);
- 	try 
-	{
-		WPDocument::parse(input, static_cast<WPXHLListenerImpl *>(&listenerImpl));
-	} 
- 	catch (FileException)
-	{
- 	    printf("ERROR: File Exception!\n");
- 	    return 1;
-	}	
- 	catch (ParseException)
-	{
- 	    printf("ERROR: Parse Exception!\n");
- 	    return 1;
-	}
-	catch (UnsupportedEncryptionException)
-	{
- 	    printf("ERROR: File is password protected!\n");
- 	    return 1;
-	}	
- 	catch (...)
-	{
- 	    printf("ERROR: Unknown Error!\n");
- 	    return 1;
-	}
+ 	WPDResult error = WPDocument::parse(gsfInput, static_cast<WPXHLListenerImpl *>(&listenerImpl));
 
+	if (error == WPD_FILE_ACCESS_ERROR)
+		fprintf(stderr, "ERROR: File Exception!\n");
+	else if (error == WPD_PARSE_ERROR)
+		fprintf(stderr, "ERROR: Parse Exception!\n");
+	else if (error == WPD_UNSUPPORTED_ENCRYPTION_ERROR)
+		fprintf(stderr, "ERROR: File is password protected!\n");
+	else if (error == WPD_OLE_ERROR)
+		fprintf(stderr, "ERROR: File is an OLE document, but does not contain a WordPerfect stream!\n");
+	else if (error != WPD_OK)
+		fprintf(stderr, "ERROR: Unknown Error!\n");
+
+	delete gsfInput;
 	g_object_unref (G_OBJECT (input));
 	gsf_shutdown();
 
+	if (error != WPD_OK)
+		return 1;
+
 	return 0;
 }
