@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002-2003 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002-2003 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -29,7 +29,8 @@
 // use the BELL code to represent a TAB for now
 #define UCS_TAB 0x0009 
 
-TextListenerImpl::TextListenerImpl()
+TextListenerImpl::TextListenerImpl(const bool isInfo) :
+	m_isInfo(isInfo)
 {
 }
 
@@ -37,22 +38,41 @@ TextListenerImpl::~TextListenerImpl()
 {
 }
 
+void TextListenerImpl::setDocumentMetaData(const WPXPropertyList &propList)
+{
+	if (!m_isInfo)
+		return;
+	WPXPropertyList::Iter propIter(propList);
+	for (propIter.rewind(); propIter.next(); )
+	{
+		printf("%s %s\n", propIter.key(), propIter()->getStr().cstr());
+	}	
+}
+
 void TextListenerImpl::closeParagraph()
 {
+	if (m_isInfo)
+		return;
 	printf("\n");
 }
 
 void TextListenerImpl::insertTab()
 {
+	if (m_isInfo)
+		return;
 	printf("%c", UCS_TAB);
 }
 
 void TextListenerImpl::insertText(const WPXString &text)
 {
+	if (m_isInfo)
+		return;
 	printf("%s", text.cstr());
 }
 
 void TextListenerImpl::insertLineBreak()
 {
+	if (m_isInfo)
+		return;
 	printf("\n");
 }
