@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2003 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -26,12 +26,13 @@
 #ifndef WP42HEURISTICS_H
 #define WP42HEURISTICS_H
 
-#include "libwpd_support.h"
+#include "WPDocument.h"
+#include "WPXStream.h"
 
 class WP42Heuristics
 {
 public:
-	static WPDConfidence isWP42FileFormat(GsfInput *input, bool partialContent);
+	static WPDConfidence isWP42FileFormat(WPXInputStream *input, bool partialContent);
 };
 
 #endif /* WP42HEURISTICS_H */
