@@ -1,6 +1,7 @@
 /* libwpd
  * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2003-2004 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2003-2004 Marc Maurer (uwog@uwog.net)
+ * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +15,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -26,7 +27,7 @@
 #include "WPXPart.h"
 #include "WP42Part.h"
 #include "WP42FileStructure.h"
-#include "WP42VariableLengthGroup.h"
+#include "WP42MultiByteFunctionGroup.h"
 #include "libwpd_internal.h"
 
 // constructPart: constructs a parseable low-level representation of part of the document
@@ -36,23 +37,14 @@
 // TODO: check the precondition :D
 WP42Part * WP42Part::constructPart(WPXInputStream *input, uint8_t readVal)
 {	
-	WPD_DEBUG_MSG(("WordPerfect: ConstructPart(readVal: 0x0%x)\n", readVal));
-		
-	// TODO: ASSERT readVal
-	
-	if (WP42_FUNCTION_GROUP_SIZE[readVal-0xC0] == -1)
-	{
-		WPD_DEBUG_MSG(("WordPerfect: constructVariableLengthGroup(input, val)\n"));
-		return WP42VariableLengthGroup::constructVariableLengthGroup(input, readVal);
-	}
-	else
-	{
-		// fixed length function group
-		
-		// for now, we just skip over the group
-		input->seek(WP42_FUNCTION_GROUP_SIZE[readVal-0xC0]-1, WPX_SEEK_CUR);
-	}
+	WPD_DEBUG_MSG(("WordPerfect: Offset: %i, ConstructPart(readVal: 0x%2x)\n", input->tell(), readVal));
 
-	WPD_DEBUG_MSG(("WordPerfect: Returning NULL from constructPart\n"));
-	return NULL;
+	if (((uint8_t)0xC0 > readVal) || ((uint8_t)0xF8 < readVal))
+	{
+		WPD_DEBUG_MSG(("WordPerfect: Returning NULL from constructPart\n"));
+		return NULL;
+	}
+	
+	WPD_DEBUG_MSG(("WordPerfect: constructMultiByteFunctionGroup(input, val)\n"));
+	return WP42MultiByteFunctionGroup::constructMultiByteFunctionGroup(input, readVal);
 }
