@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2003 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -28,6 +28,7 @@
 
 #include "WPXPart.h"
 #include "WPXParser.h"
+#include "WP42Listener.h"
 
 class WP42LLListener;
 
@@ -36,8 +37,8 @@ class WP42Part
  public:
 	virtual ~WP42Part() {}
 	
-	static WP42Part * constructPart(GsfInput *input, guint8 readVal);
-	//virtual void parse(WP42LLListener *llListener) = 0;
+	static WP42Part * constructPart(WPXInputStream *input, uint8_t readVal);
+	virtual void parse(WP42Listener *listener) = 0;
 };
 
 #endif /* WP6PART_H */
