@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -24,37 +24,36 @@
  */
 
 #include "WP6AttributeGroup.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
 
-WP6AttributeGroup::WP6AttributeGroup(GsfInput *input, guint8 groupID)
+WP6AttributeGroup::WP6AttributeGroup(WPXInputStream *input, uint8_t groupID)
 	: WP6FixedLengthGroup(groupID)
 {
 	_read(input);
 }
 
-void WP6AttributeGroup::_readContents(GsfInput *input)
+void WP6AttributeGroup::_readContents(WPXInputStream *input)
 {
-	m_attribute = (guint8)*((const guint8 *)gsf_input_read(input, sizeof(guint8), NULL));
+	m_attribute = readU8(input);
 }
 
-WP6AttributeOnGroup::WP6AttributeOnGroup(GsfInput *input, guint8 groupID)
+WP6AttributeOnGroup::WP6AttributeOnGroup(WPXInputStream *input, uint8_t groupID)
 	: WP6AttributeGroup(input, groupID)
 {
 }
 
-void WP6AttributeOnGroup::parse(WP6HLListener *listener)
+void WP6AttributeOnGroup::parse(WP6Listener *listener)
 {
 	// FIXME: handle flags
 	listener->attributeChange(true, getAttribute());
 }
 
-WP6AttributeOffGroup::WP6AttributeOffGroup(GsfInput *input, guint8 groupID)
+WP6AttributeOffGroup::WP6AttributeOffGroup(WPXInputStream *input, uint8_t groupID)
 	: WP6AttributeGroup(input, groupID)
 {
 }
 
-void WP6AttributeOffGroup::parse(WP6HLListener *listener)
+void WP6AttributeOffGroup::parse(WP6Listener *listener)
 {
 	// FIXME: handle flags
 	listener->attributeChange(false, getAttribute());
