@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2004 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
  * This library is free software; you can redistribute it and/or
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -25,7 +25,6 @@
  */
 
 #include "WP6CharacterGroup.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
 
 /*************************************************************************
@@ -33,15 +32,15 @@
  *************************************************************************/
 
 WP6CharacterGroup_SetAlignmentCharacterSubGroup::WP6CharacterGroup_SetAlignmentCharacterSubGroup(WPXInputStream *input) :
-	m_characterSet(0),
-	m_character(0)
+	m_character(0),
+	m_characterSet(0)
 {
 	uint16_t charWord = readU16(input);
 	m_characterSet = (charWord & 0xFF00) >> 8;
 	m_character = (charWord & 0xFF);
 }
 
-void WP6CharacterGroup_SetAlignmentCharacterSubGroup::parse(WP6HLListener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
+void WP6CharacterGroup_SetAlignmentCharacterSubGroup::parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
 {
 	const uint16_t *chars;
 	int len;
@@ -62,7 +61,7 @@ WP6CharacterGroup_ColorSubGroup::WP6CharacterGroup_ColorSubGroup(WPXInputStream
 	WPD_DEBUG_MSG(("WordPerfect: Character Group Color subgroup info (red: %i, green: %i, blue: %i)\n", m_red, m_green, m_blue));
 }
 
-void WP6CharacterGroup_ColorSubGroup::parse(WP6HLListener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
+void WP6CharacterGroup_ColorSubGroup::parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
 {
 	listener->characterColorChange(m_red, m_green, m_blue);
 }
@@ -77,7 +76,7 @@ WP6CharacterGroup_CharacterShadingChangeSubGroup::WP6CharacterGroup_CharacterSha
 	WPD_DEBUG_MSG(("WordPerfect: Character Group Character Shading Change subgroup info (shading: %i)\n", m_shading));
 }
 
-void WP6CharacterGroup_CharacterShadingChangeSubGroup::parse(WP6HLListener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
+void WP6CharacterGroup_CharacterShadingChangeSubGroup::parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
 {
 	listener->characterShadingChange(m_shading);
 }
@@ -95,7 +94,7 @@ WP6CharacterGroup_FontFaceChangeSubGroup::WP6CharacterGroup_FontFaceChangeSubGro
 	WPD_DEBUG_MSG(("WordPerfect: Character Group Font Face Change subgroup info (old matched point size: %i, hash: %i, matched font index: %i, matched font point size: %i\n", m_oldMatchedPointSize, m_hash, m_matchedFontIndex, m_matchedFontPointSize));
 }
 
-void WP6CharacterGroup_FontFaceChangeSubGroup::parse(WP6HLListener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
+void WP6CharacterGroup_FontFaceChangeSubGroup::parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
 {
 	WPD_DEBUG_MSG(("WordPerfect: FontFaceChangeSubGroup parsing\n"));
 	// TODO: check that we have 1 prefix id
@@ -103,13 +102,31 @@ void WP6CharacterGroup_FontFaceChangeSubGroup::parse(WP6HLListener *listener, co
 	listener->fontChange(m_matchedFontPointSize, prefixIDs[0]);
 }
 
+/*************************************************************************
+ * WP6CharacterGroup_FontSizeChangeSubGroups
+ *************************************************************************/
+
+WP6CharacterGroup_FontSizeChangeSubGroup::WP6CharacterGroup_FontSizeChangeSubGroup(WPXInputStream *input)
+{
+	m_desiredFontPointSize = readU16(input);
+	WPD_DEBUG_MSG(("WordPerfect: Character Group Font Size Change subgroup info (desired font point size: %i\n", m_desiredFontPointSize));
+}
+
+void WP6CharacterGroup_FontSizeChangeSubGroup::parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
+{
+	WPD_DEBUG_MSG(("WordPerfect: FontSizeChangeSubGroup parsing\n"));
+	// TODO: check that we have 1 prefix id
+	// emit an exception otherwise
+	listener->fontChange(m_desiredFontPointSize, prefixIDs[0]);
+}
+
 /*************************************************************************
  * WP6CharacterGroup_SetDotLeaderCharactersSubGroup
  *************************************************************************/
 
 WP6CharacterGroup_SetDotLeaderCharactersSubGroup::WP6CharacterGroup_SetDotLeaderCharactersSubGroup(WPXInputStream *input) :
-	m_characterSet(0),
 	m_character(0),
+	m_characterSet(0),
 	m_numberOfSpaces(0)
 {
 	uint16_t charWord = readU16(input);
@@ -118,7 +135,7 @@ WP6CharacterGroup_SetDotLeaderCharactersSubGroup::WP6CharacterGroup_SetDotLeader
 	m_numberOfSpaces = readU8(input);
 }
 
-void WP6CharacterGroup_SetDotLeaderCharactersSubGroup::parse(WP6HLListener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
+void WP6CharacterGroup_SetDotLeaderCharactersSubGroup::parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
 {
 	const uint16_t *chars;
 	int len;
@@ -139,7 +156,7 @@ WP6CharacterGroup_ParagraphNumberOnSubGroup::WP6CharacterGroup_ParagraphNumberOn
 	m_flag = readU8(input);
 }
 
-void WP6CharacterGroup_ParagraphNumberOnSubGroup::parse(WP6HLListener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
+void WP6CharacterGroup_ParagraphNumberOnSubGroup::parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
 {
 	listener->paragraphNumberOn(m_outlineHash, m_level, m_flag);
 }
@@ -156,7 +173,7 @@ WP6CharacterGroup_TableDefinitionOnSubGroup::WP6CharacterGroup_TableDefinitionOn
 	// TODO: add the remaining table properties here
 }
 
-void WP6CharacterGroup_TableDefinitionOnSubGroup::parse(WP6HLListener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
+void WP6CharacterGroup_TableDefinitionOnSubGroup::parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
 {
 	listener->defineTable(m_position, m_leftOffset);
 }
@@ -167,10 +184,9 @@ void WP6CharacterGroup_TableDefinitionOnSubGroup::parse(WP6HLListener *listener,
 
 WP6CharacterGroup_TableDefinitionOffSubGroup::WP6CharacterGroup_TableDefinitionOffSubGroup(WPXInputStream *input)
 {
-
 }
 
-void WP6CharacterGroup_TableDefinitionOffSubGroup::parse(WP6HLListener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
+void WP6CharacterGroup_TableDefinitionOffSubGroup::parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
 {
 	// the table is degined now; start the table
 	listener->startTable();
@@ -187,17 +203,16 @@ WP6CharacterGroup_TableColumnSubGroup::WP6CharacterGroup_TableColumnSubGroup(WPX
 
 	m_leftGutter = readU16(input);
 	m_rigthGutter = readU16(input);
-	m_attribWord1 = readU16(input);
-	m_attribWord2 = readU16(input);
-	m_alignment = readU8(input);
+	m_attributes = (readU32(input) & 0x0003FFFF);
+	m_alignment = (readU8(input) & 0x07);
 	m_absPosFromRight = readU16(input);
 	m_numberType = readU16(input);
 	m_currencyIndex = readU8(input);
 }
 
-void WP6CharacterGroup_TableColumnSubGroup::parse(WP6HLListener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
+void WP6CharacterGroup_TableColumnSubGroup::parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
 {
-	listener->addTableColumnDefinition(m_width, m_leftGutter, m_rigthGutter);
+	listener->addTableColumnDefinition(m_width, m_leftGutter, m_rigthGutter, m_attributes, m_alignment);
 }
 
 /*************************************************************************
@@ -223,9 +238,11 @@ void WP6CharacterGroup::_readContents(WPXInputStream *input)
 	switch (getSubGroup())
 	{
 		case WP6_CHARACTER_GROUP_FONT_FACE_CHANGE:
-		case WP6_CHARACTER_GROUP_FONT_SIZE_CHANGE:
 			m_subGroupData = new WP6CharacterGroup_FontFaceChangeSubGroup(input);
 			break;
+		case WP6_CHARACTER_GROUP_FONT_SIZE_CHANGE:
+			m_subGroupData = new WP6CharacterGroup_FontSizeChangeSubGroup(input);
+			break;
 		case WP6_CHARACTER_GROUP_SET_ALIGNMENT_CHARACTER:
 			m_subGroupData = new WP6CharacterGroup_SetAlignmentCharacterSubGroup(input);
 			break;
@@ -255,7 +272,7 @@ void WP6CharacterGroup::_readContents(WPXInputStream *input)
 	}
 }
 
-void WP6CharacterGroup::parse(WP6HLListener *listener)
+void WP6CharacterGroup::parse(WP6Listener *listener)
 {
 	WPD_DEBUG_MSG(("WordPerfect: handling a Character group\n"));
 
