@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -24,17 +24,17 @@
  */
 
 #include "WP6ColumnGroup.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
+#include "WPXFileStructure.h"
 
-WP6ColumnGroup::WP6ColumnGroup(GsfInput *input) :
+WP6ColumnGroup::WP6ColumnGroup(WPXInputStream *input) :
 	WP6VariableLengthGroup(),
 	m_margin(0)
 {
 	_read(input);
 }
 
-void WP6ColumnGroup::_readContents(GsfInput *input)
+void WP6ColumnGroup::_readContents(WPXInputStream *input)
 {
 	// this group can contain different kinds of data, thus we need to read
 	// the contents accordingly	
@@ -43,18 +43,39 @@ void WP6ColumnGroup::_readContents(GsfInput *input)
 		case 0: // Left Margin Set
 		case 1: // Right Margin Set
 			{
-				m_margin = gsf_le_read_guint16(input);
+				m_margin = readU16(input);
 				WPD_DEBUG_MSG(("WordPerfect: Read column group margin size (margin: %i)\n", m_margin));
 			}
 			break;
 		case 2:
 			{
-				m_colType = gsf_le_read_guint8(input);
-				for (int i=0; i<4; i++) 
+				m_colType = readU8(input);
+				uint32_t tmpRowSpacing = readU32(input);
+				int16_t tmpRowSpacingIntegerPart = (int16_t)((tmpRowSpacing & 0xffff0000) >> 16);
+				float tmpRowSpacingFractionalPart = (float)((double)(tmpRowSpacing & 0xffff)/(double)0x10000);
+				m_rowSpacing = (float)tmpRowSpacingIntegerPart + tmpRowSpacingFractionalPart;
+				m_numColumns = readU8(input);
+				uint8_t tmpDefinition;
+				uint16_t tmpWidth;
+				if (m_numColumns > 1)
+				{
+					for (int i=0; i<((2*m_numColumns)-1); i++)
 					{
-						m_rowSpacing[i] = gsf_le_read_guint8(input);
+						tmpDefinition = readU8(input);
+						tmpWidth = readU16(input);
+						if ((tmpDefinition & 0x01) == 0x01)
+						{
+							m_isFixedWidth.push_back(true);
+							m_columnWidth.push_back((float)((double)tmpWidth/(double)WPX_NUM_WPUS_PER_INCH));
+						}
+						else
+						{
+							m_isFixedWidth.push_back(false);
+							m_columnWidth.push_back((float)((double)tmpWidth/(double)0x10000));
+						}	
+						
 					}
-				m_numColumns = gsf_le_read_guint8(input);
+				}
 				WPD_DEBUG_MSG(("WordPerfect: Column type: %d\n", m_colType & 0x03));
 				WPD_DEBUG_MSG(("WordPerfect: Numer of columns: %d\n", m_numColumns));				
 			}
@@ -68,41 +89,47 @@ void WP6ColumnGroup::_readContents(GsfInput *input)
 	}
 }
 
-void WP6ColumnGroup::parse(WP6HLListener *listener)
+void WP6ColumnGroup::parse(WP6Listener *listener)
 {
-	WPD_DEBUG_MSG(("WordPerfect: handling an Column group\n"));
-	
+	WPD_DEBUG_MSG(("WordPerfect: handling a Column group\n"));
+
+	if (getFlags() & 0x40)  // Ignore function flag
+		return;
+		
 	switch (getSubGroup())
 	{
 		case 0: // Left Margin Set
-		case 1: // Right Margin Set
 			{						
-				listener->marginChange(getSubGroup(), m_margin);
+				listener->marginChange(WPX_LEFT, m_margin);
 			}
 			break;
-		case 2: // TODO: Define Text Columns, Partially implemented.
+		case 1: // Right Margin Set
+			{						
+				listener->marginChange(WPX_RIGHT, m_margin);
+			}
+			break;
+		case 2: // Define Text Columns
 			{
 				// number of columns = {0,1} means columns off
 				if ((m_numColumns == 0) || (m_numColumns == 1))
 				{
-					listener->columnChange(1); // the value "1" is bugus, the false bool gives you all the information you need here
+					listener->columnChange(NEWSPAPER, 1, m_columnWidth, m_isFixedWidth); // the value "1" is bugus, the false bool gives you all the information you need here
 				} 
 				else
 				{
-					// TODO: pass the column type to the listener
 					switch (m_colType & 0x03)
 					{
 						case WP6_COLUMN_TYPE_NEWSPAPER:
-							listener->columnChange(m_numColumns);
+							listener->columnChange(NEWSPAPER, m_numColumns, m_columnWidth, m_isFixedWidth);
 							break;
 						case WP6_COLUMN_TYPE_NEWSPAPER_VERTICAL_BALANCE:
-							listener->columnChange(m_numColumns);
+							listener->columnChange(NEWSPAPER_VERTICAL_BALANCE, m_numColumns, m_columnWidth, m_isFixedWidth);
 							break;
 						case WP6_COLUMN_TYPE_PARALLEL:
-							listener->columnChange(m_numColumns);
+							listener->columnChange(PARALLEL, m_numColumns, m_columnWidth, m_isFixedWidth);
 							break;
 						case WP6_COLUMN_TYPE_PARALLEL_PROTECT:
-							listener->columnChange(m_numColumns);
+							listener->columnChange(PARALLEL_PROTECT, m_numColumns, m_columnWidth, m_isFixedWidth);
 							break;
 						default: // something else we don't support, since it isn't in the docs
 							break;
