@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -30,15 +30,15 @@
 class WP6DefaultInitialFontPacket : public WP6PrefixDataPacket
 {
  public:
-	WP6DefaultInitialFontPacket(GsfInput *input, int id, guint32 dataOffset, guint32 dataSize);
-	virtual void _readContents(GsfInput *input);
-	const guint16 getInitialFontDescriptorPID() const { return m_initialFontDescriptorPID; }
-	const guint16 getPointSize() const { return m_pointSize; }
-	virtual void parse(WP6HLListener *listener) const;
+	WP6DefaultInitialFontPacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize);
+	void _readContents(WPXInputStream *input);
+	const uint16_t getInitialFontDescriptorPID() const { return m_initialFontDescriptorPID; }
+	const uint16_t getPointSize() const { return m_pointSize; }
+	void parse(WP6Listener *listener) const;
 	
  private:
-	guint16 m_numPrefixIDs;
-	guint16 m_initialFontDescriptorPID;
-	guint16 m_pointSize;
+	uint16_t m_numPrefixIDs;
+	uint16_t m_initialFontDescriptorPID;
+	uint16_t m_pointSize;
 };
 #endif
