@@ -1,7 +1,7 @@
 
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -25,7 +25,6 @@
  */
 
 #include "WP6DisplayNumberReferenceGroup.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
 
 WP6DisplayNumberReferenceGroup::WP6DisplayNumberReferenceGroup(WPXInputStream *input) :
@@ -41,7 +40,7 @@ void WP6DisplayNumberReferenceGroup::_readContents(WPXInputStream *input)
 		m_levelNumberToDisplay = readU8(input);
 }
 
-void WP6DisplayNumberReferenceGroup::parse(WP6HLListener *listener)
+void WP6DisplayNumberReferenceGroup::parse(WP6Listener *listener)
 {
 	WPD_DEBUG_MSG(("WordPerfect: handling a DisplayNumberReference group\n"));
 	
