@@ -1,7 +1,8 @@
 /* libwpd
  * Copyright (C) 2003 Net Integration Technologies
  * Copyright (C) 2002-2003 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
+ * Copyright (C) 2004 Fridrich Strba (fridrich.strba@bluewin.ch)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -15,7 +16,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -25,24 +26,37 @@
  */
 
 #include "WP6EOLGroup.h"
-#include "WP6LLListener.h"
-#include "WPXHLListener.h"
+#include "WPXListener.h"
 #include "libwpd_internal.h"
 
 #include "WP6Parser.h" // for TableException
 #include "WP6FillStylePacket.h" // for the fill packet
 
-WP6EOLGroup::WP6EOLGroup(GsfInput *input) :	
+WP6EOLGroup::WP6EOLGroup(WPXInputStream *input) :	
 	WP6VariableLengthGroup(),
 	m_colSpan(1),
 	m_rowSpan(1),
 	m_boundFromLeft(false),
 	m_boundFromAbove(false),
 	
+	m_useCellAttributes(false),
+	m_useCellJustification(false),
+	m_ignoreInCalculations(false),
+	m_cellIsLocked(false),
+	m_cellAttributes(0),
+	m_cellJustification(0),
+	m_cellVerticalAlign(TOP),
+	
 	m_cellFgColor(NULL),
 	m_cellBgColor(NULL),
+	m_cellBorderColor(new RGBSColor(0x00,0x00,0x00,0x64)),
 	
-	m_cellBorders(0x00)
+	m_cellBorders(0x00),
+	
+	m_isHeaderRow(false),
+	m_isMinimumHeight(true),
+	m_rowHeight(0),
+	m_isDontEndAParagraphStyleForThisHardReturn(false)
 {
 	_read(input);
 }
@@ -50,32 +64,55 @@ WP6EOLGroup::WP6EOLGroup(GsfInput *input) :
 WP6EOLGroup::~WP6EOLGroup()
 {
 	DELETEP(m_cellFgColor);
-	DELETEP(m_cellBgColor);	
+	DELETEP(m_cellBgColor);
+	DELETEP(m_cellBorderColor);	
 }
 
-void WP6EOLGroup::_readContents(GsfInput *input)
+void WP6EOLGroup::_readContents(WPXInputStream *input)
 {
 	WPD_DEBUG_MSG(("WordPerfect: EOL Group: Reading Embedded Sub-Function Data\n"));
-	guint16 sizeDeletableSubFunctionData;
-	guint16 startPosition = gsf_input_tell(input);
-	sizeDeletableSubFunctionData = gsf_le_read_guint16(input);		
-	WPD_DEBUG_MSG(("WordPerfect: EOL Group: Size of Deletable Sub-Function Data: %ld,  Size of Deletable and Non-deletable sub-function data: %ld\n", (long) sizeDeletableSubFunctionData, getSizeNonDeletable()));
-	WPD_CHECK_FILE_SEEK_ERROR(gsf_input_seek(input, sizeDeletableSubFunctionData, G_SEEK_CUR));
-	while (gsf_input_tell(input) < (startPosition + getSizeNonDeletable()))
+	unsigned int startPosition = input->tell();
+	uint16_t sizeDeletableSubFunctionData = readU16(input);		
+	WPD_DEBUG_MSG(("WordPerfect: EOL Group: Size of Deletable Sub-Function Data: %ld,  Size of Deletable and Non-deletable sub-function data: %ld\n", (long) sizeDeletableSubFunctionData, (long) getSizeNonDeletable()));
+	if ((long)sizeDeletableSubFunctionData > (long)getSizeNonDeletable())
 	{
-		guint8 byte;
-		guint16 numBytesToSkip = 0;
-		byte = gsf_le_read_guint8(input);
-		gsf_off_t startPosition2 = gsf_input_tell(input);
+		WPD_DEBUG_MSG(("WordPerfect: EOL Group: Possible corruption detected, bailing out\n"));
+		throw FileException();
+	}
+
+	input->seek(sizeDeletableSubFunctionData, WPX_SEEK_CUR);
+	while (input->tell() < (startPosition + getSizeNonDeletable()))
+	{
+		uint8_t byte;
+		uint16_t numBytesToSkip = 0;
+		byte = readU8(input);
+		long startPosition2 = input->tell();
 		switch (byte)
 		{
 			case WP6_EOL_GROUP_ROW_INFORMATION:
 				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: ROW_INFORMATION\n"));
 				numBytesToSkip = WP6_EOL_GROUP_ROW_INFORMATION_SIZE;
+				uint8_t rowFlags;
+				rowFlags = readU8(input);
+				if ((rowFlags & 0x04) == 0x04)
+					m_isHeaderRow = true;
+				if ((rowFlags & 0x02) == 0x02)
+				{
+					if ((rowFlags & 0x10) == 0x10)
+						m_isMinimumHeight = true;
+					else
+						m_isMinimumHeight = false;
+					m_rowHeight = readU16(input);
+				}
+				else
+				{
+					m_isMinimumHeight = true;
+					m_rowHeight = 0x0000;
+				}
 				break;
 			case WP6_EOL_GROUP_CELL_FORMULA:
-				guint16 embeddedSubGroupSize;
-				embeddedSubGroupSize = gsf_le_read_guint16(input);
+				uint16_t embeddedSubGroupSize;
+				embeddedSubGroupSize = readU16(input);
 				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: CELL_FORMULA (length: %ld)\n", 
 						   (long) embeddedSubGroupSize));
 				numBytesToSkip = embeddedSubGroupSize;
@@ -91,16 +128,49 @@ void WP6EOLGroup::_readContents(GsfInput *input)
 			case WP6_EOL_GROUP_CELL_INFORMATION:
 				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: CELL_INFORMATION\n"));
 				numBytesToSkip = WP6_EOL_GROUP_CELL_INFORMATION_SIZE;
+				uint8_t cellFlag, tmpCellVerticalAlign;
+				uint16_t attributeWord1, attributeWord2;
+				cellFlag = readU8(input);
+				if ((cellFlag & 0x01) == 0x01)
+					m_useCellAttributes = true;
+				if ((cellFlag & 0x02) == 0x02)
+					m_useCellJustification = true;
+				if ((cellFlag & 0x40) == 0x40)
+					m_ignoreInCalculations = true;
+				if ((cellFlag & 0x80) == 0x80)
+					m_cellIsLocked = true;
+				m_cellJustification = (readU8(input) & 0x07);
+				tmpCellVerticalAlign = readU8(input);
+				switch (tmpCellVerticalAlign & 0x03)
+				{
+				case 0x00: // top
+					m_cellVerticalAlign = TOP;
+					break;
+				case 0x01: // center
+					m_cellVerticalAlign = MIDDLE;
+					break;
+				case 0x02: // bottom
+					m_cellVerticalAlign = BOTTOM;
+					break;
+				case 0x03: // full
+					m_cellVerticalAlign = FULL;
+					break;
+				default:
+					break;
+				}				
+				attributeWord1 = readU16(input);
+				attributeWord2 = readU16(input);
+				m_cellAttributes = ((attributeWord2 & 0x03) << 16) + attributeWord1;
 				break;
 			case WP6_EOL_GROUP_CELL_SPANNING_INFORMATION:
 				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: CELL_SPANNING_INFORMATION\n"));
 				numBytesToSkip = WP6_EOL_GROUP_CELL_SPANNING_INFORMATION_SIZE;
-				guint8 numCellsSpannedHorizontally;
-				guint8 numCellsSpannedVertically;
-				numCellsSpannedHorizontally = gsf_le_read_guint8(input);
-				numCellsSpannedVertically = gsf_le_read_guint8(input);
+				uint8_t numCellsSpannedHorizontally;
+				uint8_t numCellsSpannedVertically;
+				numCellsSpannedHorizontally = readU8(input);
+				numCellsSpannedVertically = readU8(input);
 				WPD_DEBUG_MSG(("WordPerfect: num cells spanned (h:%ld, v:%ld)\n", 
-						   numCellsSpannedHorizontally, numCellsSpannedVertically));
+						   (long) numCellsSpannedHorizontally, (long) numCellsSpannedVertically));
 				if (numCellsSpannedHorizontally >= 128)
 					m_boundFromLeft = true;
 				else
@@ -113,17 +183,17 @@ void WP6EOLGroup::_readContents(GsfInput *input)
 			case WP6_EOL_GROUP_CELL_FILL_COLORS:
 				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: CELL_FILL_COLORS\n"));
 				numBytesToSkip = WP6_EOL_GROUP_CELL_FILL_COLORS_SIZE;
-				guint8 fR, fG, fB, fS;
-				guint8 bR, bG, bB, bS;
+				uint8_t fR, fG, fB, fS;
+				uint8_t bR, bG, bB, bS;
 			
-				fR = gsf_le_read_guint8(input);
-				fG = gsf_le_read_guint8(input);
-				fB = gsf_le_read_guint8(input);
-				fS = gsf_le_read_guint8(input);
-				bR = gsf_le_read_guint8(input);
-				bG = gsf_le_read_guint8(input);
-				bB = gsf_le_read_guint8(input);
-				bS = gsf_le_read_guint8(input);
+				fR = readU8(input);
+				fG = readU8(input);
+				fB = readU8(input);
+				fS = readU8(input);
+				bR = readU8(input);
+				bG = readU8(input);
+				bB = readU8(input);
+				bS = readU8(input);
 			
 				m_cellFgColor = new RGBSColor(fR,fG,fB,fS);
 				m_cellBgColor = new RGBSColor(bR,bG,bB,bS);
@@ -134,6 +204,14 @@ void WP6EOLGroup::_readContents(GsfInput *input)
 			case WP6_EOL_GROUP_CELL_LINE_COLOR:
 				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: CELL_LINE_COLOR\n"));
 				numBytesToSkip = WP6_EOL_GROUP_CELL_LINE_COLOR_SIZE;
+
+				m_cellBorderColor->m_r = readU8(input);
+				m_cellBorderColor->m_g = readU8(input);
+				m_cellBorderColor->m_b = readU8(input);
+				m_cellBorderColor->m_s = readU8(input);
+				
+				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Border Color (%i, %i, %i, %i)\n",
+					       m_cellBorderColor->m_r, m_cellBorderColor->m_g, m_cellBorderColor->m_b, m_cellBorderColor->m_s));				
 				break;
 			case WP6_EOL_GROUP_CELL_NUMBER_TYPE:
 				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: CELL_NUMBER_TYPE\n"));		
@@ -146,7 +224,7 @@ void WP6EOLGroup::_readContents(GsfInput *input)
 			case WP6_EOL_GROUP_CELL_PREFIX_FLAG:
 				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: CELL_PREFIX_FLAG\n"));	
 				numBytesToSkip = WP6_EOL_GROUP_CELL_PREFIX_FLAG_SIZE;
-				m_cellBorders = *(const guint8 *)gsf_input_read(input, sizeof(guint8), NULL);
+				m_cellBorders = readU8(input);
 				break;
 			case WP6_EOL_GROUP_CELL_RECALCULATION_ERROR_NUMBER:
 				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: CELL_RECALCULATION_ERROR_NUMBER\n"));
@@ -157,25 +235,30 @@ void WP6EOLGroup::_readContents(GsfInput *input)
 				numBytesToSkip = WP6_EOL_GROUP_DONT_END_A_PARAGRAPH_STYLE_FOR_THIS_HARD_RETURN_SIZE;
 				m_isDontEndAParagraphStyleForThisHardReturn = true;
 				break;
-			default:
-				// unsupported: shouldn't happen! an error may follow
-				// HACK: one document seems to have a completely bogus value within 
-				// pre-emptively throw a parsing exception
+			case 0x8e:
+			case 0x8f:
 				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: UNKNOWN SUBFUNCTION (%x) (BAD BAD BAD)\n", byte));
-				throw ParseException();
+				numBytesToSkip = readU16(input); // It seems that these two unknow sub-functions have their
+				                                 // length information embedded: <subfunction>[length]...[length]<subfunction>
+				break;
+			default:
+				WPD_DEBUG_MSG(("WordPerfect: EOL Group Embedded Sub-Function: UNKNOWN SUBFUNCTION (%x) (BAD BAD BAD)\n", byte));
+				WPD_DEBUG_MSG(("WordPerfect: Possible corruption detected, bailing out\n"));
+				throw FileException();
 		}			
 		
-		WPD_CHECK_FILE_SEEK_ERROR(gsf_input_seek(input, (startPosition2 + numBytesToSkip - 1 - gsf_input_tell(input)), G_SEEK_CUR));
+		input->seek((startPosition2 + numBytesToSkip - 1 - input->tell()), WPX_SEEK_CUR);
 	}
 }
 
-void WP6EOLGroup::parse(WP6HLListener *listener)
+void WP6EOLGroup::parse(WP6Listener *listener)
 {
 	WPD_DEBUG_MSG(("WordPerfect: handling an EOL group\n"));
 
 	// first off, grab any prefix information which may be useful
 	const RGBSColor * cellFgColor = m_cellFgColor;
 	const RGBSColor * cellBgColor = m_cellBgColor;
+	const RGBSColor * cellBorderColor = m_cellBorderColor;
 	
 	if (!cellFgColor && !cellBgColor)
 	{
@@ -198,14 +281,12 @@ void WP6EOLGroup::parse(WP6HLListener *listener)
 		case WP6_EOL_GROUP_SOFT_EOL:
 		case WP6_EOL_GROUP_SOFT_EOC:
 		case WP6_EOL_GROUP_SOFT_EOC_AT_EOP: // 0x03 (soft EOC at EOP) 
+			listener->insertCharacter((uint16_t) ' ');
+			break;
 		case WP6_EOL_GROUP_DELETABLE_HARD_EOL: // 0x17 (deletable hard EOL)
 		case WP6_EOL_GROUP_DELETABLE_HARD_EOL_AT_EOC: // 0x18 (deletable hard EOL at EOC)
 		case WP6_EOL_GROUP_DELETABLE_HARD_EOL_AT_EOP: // 0x19 (deletable hard EOL at EOP)
 		case WP6_EOL_GROUP_DELETABLE_HARD_EOP: // deletable hard EOP
-		case WP6_EOL_GROUP_DELETABLE_HARD_EOC:
-		case WP6_EOL_GROUP_DELETABLE_HARD_EOC_AT_EOP:
-			listener->insertCharacter((guint16) ' ');
-			break;
 		case WP6_EOL_GROUP_HARD_EOL:
 		case WP6_EOL_GROUP_HARD_EOL_AT_EOC:
 		case WP6_EOL_GROUP_HARD_EOL_AT_EOP:
@@ -217,6 +298,8 @@ void WP6EOLGroup::parse(WP6HLListener *listener)
 			break;
 		case WP6_EOL_GROUP_HARD_EOC: // 0x07 (hard end of column)
 		case WP6_EOL_GROUP_HARD_EOC_AT_EOP:
+		case WP6_EOL_GROUP_DELETABLE_HARD_EOC:
+		case WP6_EOL_GROUP_DELETABLE_HARD_EOC_AT_EOP:
 			listener->insertBreak(WPX_COLUMN_BREAK);
 			break;
 		case WP6_EOL_GROUP_HARD_EOP: // hard EOP
@@ -224,7 +307,13 @@ void WP6EOLGroup::parse(WP6HLListener *listener)
 			break;
 		case WP6_EOL_GROUP_TABLE_CELL: // Table Cell
 			WPD_DEBUG_MSG(("WordPerfect: EOL group: table cell\n"));
-			listener->insertCell(m_colSpan, m_rowSpan, m_boundFromLeft, m_boundFromAbove, m_cellBorders, cellFgColor, cellBgColor);
+			if (!m_boundFromLeft && !m_boundFromAbove)
+			{
+				listener->insertCell(m_colSpan, m_rowSpan, m_cellBorders, cellFgColor, cellBgColor,
+					cellBorderColor, m_cellVerticalAlign, m_useCellAttributes, m_cellAttributes);
+				if (m_useCellJustification)
+					listener->justificationChange(m_cellJustification);
+			}
 			break;
 		case WP6_EOL_GROUP_TABLE_ROW_AND_CELL:
 		case WP6_EOL_GROUP_TABLE_ROW_AT_EOC:
@@ -233,9 +322,16 @@ void WP6EOLGroup::parse(WP6HLListener *listener)
 		case WP6_EOL_GROUP_TABLE_ROW_AT_HARD_EOC_AT_HARD_EOP:
 		case WP6_EOL_GROUP_TABLE_ROW_AT_HARD_EOP:
 			WPD_DEBUG_MSG(("WordPerfect: EOL group: table row and cell\n"));
-			listener->insertRow();
+			
+			listener->insertRow(m_rowHeight, m_isMinimumHeight, m_isHeaderRow);
 			// the cellBorders variable already represent the cell border bits as well
-			listener->insertCell(m_colSpan, m_rowSpan, m_boundFromLeft, m_boundFromAbove, m_cellBorders, cellFgColor, cellBgColor);
+			if (!m_boundFromLeft && !m_boundFromAbove)
+			{
+				listener->insertCell(m_colSpan, m_rowSpan, m_cellBorders, cellFgColor, cellBgColor,
+					cellBorderColor, m_cellVerticalAlign, m_useCellAttributes, m_cellAttributes);
+				if (m_useCellJustification)
+					listener->justificationChange(m_cellJustification);
+			}
 			break;
 		case WP6_EOL_GROUP_TABLE_OFF:
 		case WP6_EOL_GROUP_TABLE_OFF_AT_EOC:
