@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2003 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2002 Ariya Hidayat <ariyahidayat@yahoo.de>
  *  
  * This library is free software; you can redistribute it and/or
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -26,7 +26,6 @@
 
 #include "WP6ExtendedCharacterGroup.h"
 #include "WP6FileStructure.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
 
 WP6ExtendedCharacterGroup::WP6ExtendedCharacterGroup(WPXInputStream *input, uint8_t groupID) :
@@ -43,7 +42,7 @@ void WP6ExtendedCharacterGroup::_readContents(WPXInputStream *input)
 	m_characterSet = readU8(input);
 }
 
-void WP6ExtendedCharacterGroup::parse(WP6HLListener *listener)
+void WP6ExtendedCharacterGroup::parse(WP6Listener *listener)
 {
 	const uint16_t *chars;
 	int len = extendedCharacterWP6ToUCS2(m_character,
