@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -27,19 +27,21 @@
 #define WP6EXTENDEDDOCUMENTSUMMARYPACKET_H
 #include "WP6PrefixDataPacket.h"
 #include "WP6FileStructure.h"
-#include "WP6HLListener.h"
+#include "WP6Listener.h"
+#include "WPXStream.h"
+#include "WPXMemoryStream.h"
 
 class WP6ExtendedDocumentSummaryPacket : public WP6PrefixDataPacket
 {
  public:
-	WP6ExtendedDocumentSummaryPacket(GsfInput *input, int id, guint32 dataOffset, guint32 dataSize);
-	virtual ~WP6ExtendedDocumentSummaryPacket();
-	virtual void _readContents(GsfInput *input);
-	virtual void parse(WP6HLListener *listener) const;
+	WP6ExtendedDocumentSummaryPacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize);
+	~WP6ExtendedDocumentSummaryPacket();
+	void _readContents(WPXInputStream *input);
+	void parse(WP6Listener *listener) const;
 
  private:              
-	guint16 m_dataSize;
-	GsfInput *m_stream;
+	uint16_t m_dataSize;
+	mutable WPXMemoryInputStream *m_stream;
 	
 };
 #endif /* WP6EXTENDEDDOCUMENTSUMMARYPACKET_H */
