@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002-2003 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002-2003 Marc Maurer (uwog@uwog.net)
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -32,9 +32,6 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 /* standard sizes */
 #define WP6_NUM_LIST_LEVELS 8
 
-/* Misc. Junk */
-#define WP6_NUM_EXTRA_WPU 19
-
 /* header defines */
 #define WP6_HEADER_DOCUMENT_SIZE_OFFSET 20
 #define WP6_HEADER_INDEX_HEADER_POINTER_OFFSET 14
@@ -83,7 +80,6 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP6_INDEX_HEADER_OUTLINE_STYLE_UPPERCASE_NUMBERING 2
 #define WP6_INDEX_HEADER_OUTLINE_STYLE_LOWERCASE_ROMAN_NUMBERING 3
 #define WP6_INDEX_HEADER_OUTLINE_STYLE_UPPERCASE_ROMAN_NUMBERING 4
-#define WP6_NUM_LIST_LEVELS 8
 
 #define WP6_VARIABLE_GROUP_PREFIX_ID_BIT 128 /* bit 7 */
 
@@ -292,7 +288,6 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP6_FOOTNOTE_ENDNOTE_GROUP_ENDNOTE_OFF 0x03
 
 /* Header/footer Group */
-#define WP6_NUM_HEADER_FOOTER_TYPES 6
 #define WP6_HEADER_FOOTER_GROUP_HEADER_A 0x00
 #define WP6_HEADER_FOOTER_GROUP_HEADER_B 0x01
 #define WP6_HEADER_FOOTER_GROUP_FOOTER_A 0x02
