@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -31,9 +31,9 @@
 class WP6FootnoteEndnoteGroup : public WP6VariableLengthGroup
 {
  public:
-	WP6FootnoteEndnoteGroup(GsfInput *input);	
-	virtual void _readContents(GsfInput *input);
-	virtual void parse(WP6HLListener *listener);
+	WP6FootnoteEndnoteGroup(WPXInputStream *input);	
+	void _readContents(WPXInputStream *input);
+	void parse(WP6Listener *listener);
 };
 
 #endif /* WP6FOOTNOTEENDNOTEGROUP_H */
