@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -24,23 +24,22 @@
  */
 
 #include "WP6HeaderFooterGroup.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
 
-WP6HeaderFooterGroup::WP6HeaderFooterGroup(GsfInput *input) :
+WP6HeaderFooterGroup::WP6HeaderFooterGroup(WPXInputStream *input) :
 	WP6VariableLengthGroup()
 {
 	_read(input);
 }
 
-void WP6HeaderFooterGroup::_readContents(GsfInput *input)
+void WP6HeaderFooterGroup::_readContents(WPXInputStream *input)
 {
-	m_occurenceBits = gsf_le_read_guint16(input);
+	m_occurenceBits = readU8(input);
 }
 
-void WP6HeaderFooterGroup::parse(WP6HLListener *listener)
+void WP6HeaderFooterGroup::parse(WP6Listener *listener)
 {
-	WPD_DEBUG_MSG(("WordPerfect: handling an HeaderFooter group\n"));
+	WPD_DEBUG_MSG(("WordPerfect: handling a HeaderFooter group\n"));
 
 	if (getNumPrefixIDs() > 0) // FIXME: perhaps we should throw an exception if this isn't true..
 	{
