@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -27,7 +27,7 @@
 #include "WP6OutlineStylePacket.h"
 #include "libwpd_internal.h"
 
-WP6OutlineStylePacket::WP6OutlineStylePacket(GsfInput *input, int id, guint32 dataOffset, guint32 dataSize) 
+WP6OutlineStylePacket::WP6OutlineStylePacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize) 
 	: WP6PrefixDataPacket(input)
 {
 	_read(input, dataOffset, dataSize);
@@ -37,18 +37,18 @@ WP6OutlineStylePacket::~WP6OutlineStylePacket()
 {
 }
 
-void WP6OutlineStylePacket::_readContents(GsfInput *input)
+void WP6OutlineStylePacket::_readContents(WPXInputStream *input)
 {
 	unsigned int i;
 
-	m_numPIDs = gsf_le_read_guint16(input);
+	m_numPIDs = readU16(input);
 	for (i=0; i<WP6_NUM_LIST_LEVELS; i++) 
-		m_paragraphStylePIDs[i] = gsf_le_read_guint16(input); // seemingly useless
-	m_outlineFlags = gsf_le_read_guint8(input);
-	m_outlineHash = gsf_le_read_guint16(input);
+		m_paragraphStylePIDs[i] = readU16(input); // seemingly useless
+	m_outlineFlags = readU8(input);
+	m_outlineHash = readU16(input);
 	for (i=0; i<WP6_NUM_LIST_LEVELS; i++)  
-		m_numberingMethods[i] = gsf_le_read_guint8(input);
-	m_tabBehaviourFlag = gsf_le_read_guint8(input);
+		m_numberingMethods[i] = readU8(input);
+	m_tabBehaviourFlag = readU8(input);
 	
 	WPD_DEBUG_MSG(("WordPerfect: Read Outline Style Packet (numPrefixIDs: %i, outlineHash: %i, outlineFlags: %i, tab behaviour flag: %i)\n", (int) m_numPIDs, (int) m_outlineHash, (int) m_outlineFlags, (int) m_tabBehaviourFlag));
 	WPD_DEBUG_MSG(("WordPerfect: Read Outline Style Packet (m_paragraphStylePIDs: %i %i %i %i %i %i %i %i)\n", 
@@ -60,7 +60,7 @@ void WP6OutlineStylePacket::_readContents(GsfInput *input)
                      
 }
 
-void WP6OutlineStylePacket::parse(WP6HLListener *listener) const
+void WP6OutlineStylePacket::parse(WP6Listener *listener) const
 {
 	listener->updateOutlineDefinition(indexHeader, m_outlineHash, m_numberingMethods, m_tabBehaviourFlag);
 }
