@@ -1,7 +1,8 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
- *  
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
+ * Copyright (C) 2004 Fridrich Strba (fridrich.strba@bluewin.ch)
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -14,59 +15,91 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
 
 #include "WP6PageGroup.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
 
-WP6PageGroup::WP6PageGroup(GsfInput *input) :
+WP6PageGroup::WP6PageGroup(WPXInputStream *input) :
 	WP6VariableLengthGroup(),
 	m_margin(0)
 {
 	_read(input);
 }
 
-void WP6PageGroup::_readContents(GsfInput *input)
+WP6PageGroup::~WP6PageGroup()
+{
+}
+
+void WP6PageGroup::_readContents(WPXInputStream *input)
 {
 	// this group can contain different kinds of data, thus we need to read
-	// the contents accordingly	
-	switch (getSubGroup())	
+	// the contents accordingly
+	switch (getSubGroup())
 	{
 	case WP6_PAGE_GROUP_TOP_MARGIN_SET:
 	case WP6_PAGE_GROUP_BOTTOM_MARGIN_SET:
-		m_margin = gsf_le_read_guint16(input);
+		m_margin = readU16(input);
 		WPD_DEBUG_MSG(("WordPerfect: Read page group margin size (margin: %i)\n", m_margin));
-	break;
+		break;
 	case WP6_PAGE_GROUP_SUPPRESS_PAGE_CHARACTERISTICS:
-		m_suppressedCode = gsf_le_read_guint8(input);
+		m_suppressedCode = readU8(input);
 		WPD_DEBUG_MSG(("WordPerfect: Read suppressed code (%i)\n", m_suppressedCode));
+		break;
+	case WP6_PAGE_GROUP_FORM:
+		uint8_t tmpOrientation;
+		// skip Hash values that we do not use (2+1 bytes)
+		input->seek(3, WPX_SEEK_CUR);
+		m_formLength = readU16(input);
+		m_formWidth = readU16(input);
+		m_formType = readU8(input);
+		tmpOrientation = readU8(input);
+		switch (tmpOrientation)
+		{
+		case 0x01:
+			m_formOrientation = LANDSCAPE;
+			break;
+		case 0x00:
+			m_formOrientation = PORTRAIT;
+			break;
+		default:
+			m_formOrientation = PORTRAIT;
+			break;
+		}
+		WPD_DEBUG_MSG(("WordPerfect: Read form information (length: %i), (width: %i), (form orientation: %s),\n",
+						m_formLength, m_formWidth, ((m_formOrientation==PORTRAIT)?"portrait":"landscape")));
+		break;
 	default: /* something else we don't support, since it isn't in the docs */
 		break;
 	}
 }
 
-void WP6PageGroup::parse(WP6HLListener *listener)
+void WP6PageGroup::parse(WP6Listener *listener)
 {
-	WPD_DEBUG_MSG(("WordPerfect: handling an Page group\n"));
-	
+	WPD_DEBUG_MSG(("WordPerfect: handling a Page group\n"));
+
 	switch (getSubGroup())
 	{
 	case WP6_PAGE_GROUP_TOP_MARGIN_SET:
+		listener->pageMarginChange(WPX_TOP, m_margin);
+		break;
 	case WP6_PAGE_GROUP_BOTTOM_MARGIN_SET:
-		listener->pageMarginChange(getSubGroup(), m_margin);
+		listener->pageMarginChange(WPX_BOTTOM, m_margin);
 		break;
 	case WP6_PAGE_GROUP_SUPPRESS_PAGE_CHARACTERISTICS:
 		listener->suppressPageCharacteristics(m_suppressedCode);
 		break;
+	case WP6_PAGE_GROUP_FORM:
+		listener->pageFormChange(m_formLength, m_formWidth, m_formOrientation, true);
+		break;
 	default: // something else we don't support, since it isn't in the docs
 		break;
-	}	
+	}
 }
