@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -31,17 +31,23 @@
 class WP6PageGroup : public WP6VariableLengthGroup
 {
  public:
-	WP6PageGroup(GsfInput *input);	
-	virtual void _readContents(GsfInput *input);
-	virtual void parse(WP6HLListener *listener);
+	WP6PageGroup(WPXInputStream *input);	
+	~WP6PageGroup();
+	void _readContents(WPXInputStream *input);
+	void parse(WP6Listener *listener);
 
  private:
 	// variables needed for subgroup 0 and 1 (Left/Right Margin Set)
-	guint16 m_margin;
-	guint8 m_marginType;
+	uint16_t m_margin;
+	uint8_t m_marginType;
 	// variables needed for subgroup 2 (suppress page characteristics)
-	guint8 m_suppressedCode;
-	
+	uint8_t m_suppressedCode;
+	// variables needed for subgroup 0x11 (Form)
+	uint16_t m_formLength;
+	uint16_t m_formWidth;
+	uint8_t m_formType;
+	WPXFormOrientation m_formOrientation;
+
 };
 
 #endif /* WP6PAGEGROUP_H */
