@@ -1,6 +1,7 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
+ * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +15,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -35,23 +36,34 @@
 // returns the part if it successfully creates the part, returns NULL if it can't
 // throws an exception if there is an error
 // precondition: readVal us between 0x80 and 0xFF
-WP6Part * WP6Part::constructPart(GsfInput *input, guint8 readVal)
+WP6Part * WP6Part::constructPart(WPXInputStream *input, const uint8_t readVal)
 {	
 	WPD_DEBUG_MSG(("WordPerfect: ConstructPart\n"));
 		
-	if (readVal >= (guint8)0x80 && readVal <= (guint8)0xCF)
+	if (readVal >= (uint8_t)0x80 && readVal <= (uint8_t)0xCF)
 	{
-		WPD_DEBUG_MSG(("WordPerfect: constructFixedLengthGroup(input, val)\n"));
+		WPD_DEBUG_MSG(("WordPerfect: constructSingleByteFunction(input, val=0x%.2x)\n", readVal));
 		return WP6SingleByteFunction::constructSingleByteFunction(input, readVal);
 	}
-	else if (readVal >= (guint8)0xD0 && readVal <= (guint8)0xEF)
+	else if (readVal >= (uint8_t)0xD0 && readVal <= (uint8_t)0xEF)
 	{
-		WPD_DEBUG_MSG(("WordPerfect: constructVariableLengthGroup(input, val)\n"));
+		if (!WP6VariableLengthGroup::isGroupConsistent(input, readVal))
+		{
+			WPD_DEBUG_MSG(("WordPerfect: Consistency Check (variable length) failed; ignoring this byte\n"));
+			return NULL;
+		}
+		WPD_DEBUG_MSG(("WordPerfect: constructVariableLengthGroup(input, val=0x%.2x)\n", readVal));
 		return WP6VariableLengthGroup::constructVariableLengthGroup(input, readVal);
 	}      
-	else if (readVal >= (guint8)0xF0 && readVal <= (guint8)0xFF)
+
+	else if (readVal >= (uint8_t)0xF0)
 	{
-		WPD_DEBUG_MSG(("WordPerfect: constructFixedLengthGroup(input, val)\n"));
+		if (!WP6FixedLengthGroup::isGroupConsistent(input, readVal))
+		{
+			WPD_DEBUG_MSG(("WordPerfect: Consistency Check (fixed length) failed; ignoring this byte\n"));
+			return NULL;
+		}
+		WPD_DEBUG_MSG(("WordPerfect: constructFixedLengthGroup(input, val=0x%.2x)\n", readVal));
 		return WP6FixedLengthGroup::constructFixedLengthGroup(input, readVal);
 	}
 
