@@ -1,6 +1,7 @@
-/* libwpd2
+/* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
+ * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +15,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -28,17 +29,16 @@
 
 #include "WPXPart.h"
 #include "WPXParser.h"
+#include "WP6Listener.h"
 #include "WP6FileStructure.h"
 
-class WP6LLListener;
-
 class WP6Part
 {
  public:
 	virtual ~WP6Part() {}
 	
-	static WP6Part * constructPart(GsfInput *input, guint8 readVal);
-	virtual void parse(WP6LLListener *llListener) = 0;
+	static WP6Part * constructPart(WPXInputStream *input, const uint8_t readVal);
+	virtual void parse(WP6Listener *listener) = 0;
 };
 
 
