@@ -1,6 +1,6 @@
-/* libwpd2
+/* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002-2003 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -28,33 +28,33 @@
 #include "WP6PrefixDataPacket.h"
 #include "WP6FontDescriptorPacket.h"
 #include "WP6DefaultInitialFontPacket.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
 
-WP6PrefixData::WP6PrefixData(GsfInput *input, const int numPrefixIndices) :
+WP6PrefixData::WP6PrefixData(WPXInputStream *input, const int numPrefixIndices) :
 	m_defaultInitialFontPID((-1))
 {
-	WP6PrefixIndice ** prefixIndiceArray = new (WP6PrefixIndice *)[(numPrefixIndices-1)];
-	for (guint16 i=1; i<numPrefixIndices; i++)
+	uint16_t i;
+
+	WP6PrefixIndice ** prefixIndiceArray = new WP6PrefixIndice *[(numPrefixIndices-1)];
+	for (i=1; i<numPrefixIndices; i++)
 	{
 		WPD_DEBUG_MSG(("WordPerfect: constructing prefix indice 0x%x\n", i));
 		prefixIndiceArray[(i-1)] = new WP6PrefixIndice(input, i);
 	}
 	
-	for (guint16 i=1; i<numPrefixIndices; i++) 
-		{
-			WPD_DEBUG_MSG(("WordPerfect: constructing prefix packet 0x%x\n", i));
-			WP6PrefixDataPacket *prefixDataPacket = WP6PrefixDataPacket::constructPrefixDataPacket(input, prefixIndiceArray[(i-1)]);
-			if (prefixDataPacket) {
-				m_prefixDataPacketHash[i] = prefixDataPacket;
-				m_prefixDataPacketTypeHash.insert(pair<int, WP6PrefixDataPacket *>(prefixIndiceArray[i-1]->getType(), prefixDataPacket));
-				if (dynamic_cast<WP6DefaultInitialFontPacket *>(prefixDataPacket))
-					m_defaultInitialFontPID = i;
-			}
-			
+	for (i=1; i<numPrefixIndices; i++) 
+	{
+		WPD_DEBUG_MSG(("WordPerfect: constructing prefix packet 0x%x\n", i));
+		WP6PrefixDataPacket *prefixDataPacket = WP6PrefixDataPacket::constructPrefixDataPacket(input, prefixIndiceArray[(i-1)]);
+		if (prefixDataPacket) {
+			m_prefixDataPacketHash[i] = prefixDataPacket;
+			m_prefixDataPacketTypeHash.insert(::std::map<int, WP6PrefixDataPacket *>::value_type(prefixIndiceArray[i-1]->getType(), prefixDataPacket));
+			if (dynamic_cast<WP6DefaultInitialFontPacket *>(prefixDataPacket))
+				m_defaultInitialFontPID = i;
+		}
 	}
 
-	for (guint16 i=1; i<numPrefixIndices; i++)
+	for (i=1; i<numPrefixIndices; i++)
 		delete(prefixIndiceArray[(i-1)]);
 
 	delete[] prefixIndiceArray;
@@ -78,10 +78,10 @@ const WP6PrefixDataPacket * WP6PrefixData::getPrefixDataPacket(const int prefixI
 		return NULL;
 }
 
-pair<MPDP_CIter, MPDP_CIter> * WP6PrefixData::getPrefixDataPacketsOfType(const int type) const
+std::pair<MPDP_CIter, MPDP_CIter> * WP6PrefixData::getPrefixDataPacketsOfType(const int type) const
 {
- 	pair<MPDP_CIter, MPDP_CIter> *typePair = new pair<MPDP_CIter, MPDP_CIter>;
-	pair<MPDP_CIter, MPDP_CIter> tempPair = m_prefixDataPacketTypeHash.equal_range(type);
+ 	std::pair<MPDP_CIter, MPDP_CIter> *typePair = new std::pair<MPDP_CIter, MPDP_CIter>;
+	std::pair<MPDP_CIter, MPDP_CIter> tempPair = m_prefixDataPacketTypeHash.equal_range(type);
 
  	typePair->first = tempPair.first;
  	typePair->second = tempPair.second;
