@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002-2003 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002-2003 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -25,28 +25,24 @@
 
 #ifndef WP6PREFIXDATA_H
 #define WP6PREFIXDATA_H
-#include <glib.h>
-#include <gsf/gsf-input.h>
 #include "WP6PrefixDataPacket.h"
 #include <map>
 #include <vector>
-using namespace std;
 
-class WP6LLListener;
-typedef map<int, WP6PrefixDataPacket *> DPH;	
-typedef multimap<int, WP6PrefixDataPacket *> MPDP;
+typedef std::map<int, WP6PrefixDataPacket *> DPH;	
+typedef std::multimap<int, WP6PrefixDataPacket *> MPDP;
 typedef MPDP::const_iterator MPDP_CIter;
 typedef MPDP::iterator MPDP_Iter;
 
 class WP6PrefixData
 {
  public:
-	WP6PrefixData(GsfInput *input, const int numPrefixIndices);
+	WP6PrefixData(WPXInputStream *input, const int numPrefixIndices);
 	virtual ~WP6PrefixData();
 	const WP6PrefixDataPacket *getPrefixDataPacket(const int prefixID) const;
-	pair< MPDP_CIter, MPDP_CIter > * getPrefixDataPacketsOfType(const int type) const;
+	std::pair< MPDP_CIter, MPDP_CIter > * getPrefixDataPacketsOfType(const int type) const;
 
-	const guint16 getDefaultInitialFontPID() const { return m_defaultInitialFontPID; }
+	const uint16_t getDefaultInitialFontPID() const { return m_defaultInitialFontPID; }
 
  private:
 	DPH m_prefixDataPacketHash;
