@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -35,11 +35,11 @@
 #include "libwpd.h"
 #include "libwpd_internal.h"
 
-WP6PrefixDataPacket::WP6PrefixDataPacket(GsfInput * input)
+WP6PrefixDataPacket::WP6PrefixDataPacket(WPXInputStream * input)
 {
 }
 
-WP6PrefixDataPacket * WP6PrefixDataPacket::constructPrefixDataPacket(GsfInput * input, WP6PrefixIndice *prefixIndice)
+WP6PrefixDataPacket * WP6PrefixDataPacket::constructPrefixDataPacket(WPXInputStream * input, WP6PrefixIndice *prefixIndice)
 {	       
 	switch (prefixIndice->getType())
 	{
@@ -72,9 +72,12 @@ WP6PrefixDataPacket * WP6PrefixDataPacket::constructPrefixDataPacket(GsfInput *
 	}
 }
 
-void WP6PrefixDataPacket::_read(GsfInput *input, guint32 dataOffset, guint32 dataSize)
+void WP6PrefixDataPacket::_read(WPXInputStream *input, uint32_t dataOffset, uint32_t dataSize)
 {
-	WPD_CHECK_FILE_SEEK_ERROR(gsf_input_seek(input, dataOffset, G_SEEK_SET));
+	if (!dataSize)
+		return;
+
+	input->seek(dataOffset, WPX_SEEK_SET);
 
 	_readContents(input);
 
