@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -24,21 +24,20 @@
  */
 
 #include "WP6StyleGroup.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
 
-WP6StyleGroup_GlobalOnSubGroup::WP6StyleGroup_GlobalOnSubGroup(GsfInput *input)
+WP6StyleGroup_GlobalOnSubGroup::WP6StyleGroup_GlobalOnSubGroup(WPXInputStream *input)
 {
-	m_hash = gsf_le_read_guint16(input);
-	m_systemStyleNumber = gsf_le_read_guint8(input);
+	m_hash = readU16(input);
+	m_systemStyleNumber = readU8(input);
 }
 
-void WP6StyleGroup_GlobalOnSubGroup::parse(WP6HLListener *listener, const guint8 numPrefixIDs, guint16 const *prefixIDs) const
+void WP6StyleGroup_GlobalOnSubGroup::parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const
 {
 	listener->globalOn(m_systemStyleNumber);
 }
 
-WP6StyleGroup::WP6StyleGroup(GsfInput *input) :
+WP6StyleGroup::WP6StyleGroup(WPXInputStream *input) :
 	WP6VariableLengthGroup(),
 	m_subGroupData(NULL)
 {
@@ -52,7 +51,7 @@ WP6StyleGroup::~WP6StyleGroup()
 
 }
 
-void WP6StyleGroup::_readContents(GsfInput *input)
+void WP6StyleGroup::_readContents(WPXInputStream *input)
 {
 	// this group can contain different kinds of data, thus we need to read
 	// the contents accordingly
@@ -64,7 +63,7 @@ void WP6StyleGroup::_readContents(GsfInput *input)
 	}
 }
 
-void WP6StyleGroup::parse(WP6HLListener *listener)
+void WP6StyleGroup::parse(WP6Listener *listener)
 {
 	WPD_DEBUG_MSG(("WordPerfect: handling a style group\n"));
 
