@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -24,22 +24,21 @@
  */
 
 #include "WP6UndoGroup.h"
-#include "WP6LLListener.h"
 #include "libwpd_internal.h"
 
-WP6UndoGroup::WP6UndoGroup(GsfInput *input, guint8 groupID)
+WP6UndoGroup::WP6UndoGroup(WPXInputStream *input, uint8_t groupID)
 	: WP6FixedLengthGroup(groupID)
 {
 	_read(input);
 }
 
-void WP6UndoGroup::_readContents(GsfInput *input)
+void WP6UndoGroup::_readContents(WPXInputStream *input)
 {
-	m_undoType = gsf_le_read_guint8(input);
-	m_undoLevel = gsf_le_read_guint16(input);
+	m_undoType = readU8(input);
+	m_undoLevel = readU16(input);
 }
 
-void WP6UndoGroup::parse(WP6HLListener *listener)
+void WP6UndoGroup::parse(WP6Listener *listener)
 {
 	listener->undoChange(m_undoType, m_undoLevel);
 }
