@@ -1,6 +1,6 @@
 /* libwpd
  * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2003 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -31,11 +31,11 @@
 class WP6UnsupportedFixedLengthGroup : public WP6FixedLengthGroup
 {
  public:
-	WP6UnsupportedFixedLengthGroup(GsfInput *input, guint8 groupID);	
-	virtual void parse(WP6HLListener *listener) {}
+	WP6UnsupportedFixedLengthGroup(WPXInputStream *input, uint8_t groupID);	
+	void parse(WP6Listener *listener) {}
 	
  protected:
-	virtual void _readContents(GsfInput *input) {}
+	void _readContents(WPXInputStream *input) {}
 };
 
 #endif /* WP6UNSUPPORTEDFIXEDLENGTHGROUP_H */
