@@ -1,7 +1,8 @@
 /* libwpd
  * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
- *  
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
+ * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -14,12 +15,12 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
 
@@ -32,35 +33,37 @@ class WP6VariableLengthGroup_SubGroup
 {
 public:
 	virtual ~WP6VariableLengthGroup_SubGroup() {}
-	virtual void parse(WP6HLListener *listener, const guint8 numPrefixIDs, guint16 const *prefixIDs) const = 0;
+	virtual void parse(WP6Listener *listener, const uint8_t numPrefixIDs, uint16_t const *prefixIDs) const = 0;
 };
 
 class WP6VariableLengthGroup : public WP6Part
 {
- public:
+public:
 	WP6VariableLengthGroup(); // WP6VariableLengthGroup should _never_ be constructed, only its inherited classes
 	virtual ~WP6VariableLengthGroup();
-	
-	static WP6VariableLengthGroup * WP6VariableLengthGroup::constructVariableLengthGroup(GsfInput *input, guint8 groupID);
 
- protected:
-	void _read(GsfInput *input);
-	virtual void _readContents(GsfInput *input) {} // we don't always need more information than that provided generically
+	static WP6VariableLengthGroup * constructVariableLengthGroup(WPXInputStream *input, const uint8_t groupID);
 
-	const guint8 getSubGroup() const { return m_subGroup; }
-	const guint16 getSize() const { return m_size; }
-	const guint8 getFlags() const { return m_flags; }
-	const guint8 getNumPrefixIDs() const { return m_numPrefixIDs; }
-	guint16 * const getPrefixIDs() const { return m_prefixIDs; }
-	const guint16 getSizeNonDeletable() const { return m_sizeNonDeletable; }
+	static bool isGroupConsistent(WPXInputStream *input, const uint8_t groupID);
 
- private:
-	guint8 m_subGroup;
-	guint16 m_size;
-	guint8 m_flags;
-	guint8 m_numPrefixIDs;
-	guint16 *m_prefixIDs;
-	guint16 m_sizeNonDeletable;
+protected:
+	void _read(WPXInputStream *input);
+	virtual void _readContents(WPXInputStream *input) {} // we don't always need more information than that provided generically
+
+	const uint8_t getSubGroup() const { return m_subGroup; }
+	const uint16_t getSize() const { return m_size; }
+	const uint8_t getFlags() const { return m_flags; }
+	const uint8_t getNumPrefixIDs() const { return m_numPrefixIDs; }
+	uint16_t * const getPrefixIDs() const { return m_prefixIDs; }
+	const uint16_t getSizeNonDeletable() const { return m_sizeNonDeletable; }
+
+private:
+	uint8_t m_subGroup;
+	uint16_t m_size;
+	uint8_t m_flags;
+	uint8_t m_numPrefixIDs;
+	uint16_t *m_prefixIDs;
+	uint16_t m_sizeNonDeletable;
 };
 
 #endif /* WP6VARIABLELENGTHGROUP_H */
